"use client";
import { useState, useEffect } from "react";
import { Card, CardContent } from "@/components/ui/card";
import { Tabs, TabsList, TabsTrigger, TabsContent } from "@/components/ui/tabs";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";
import { Badge } from "@/components/ui/badge";
import { getStatusClass, getStatusText } from "@/lib/orderStatusHelpers";
import {
  Select,
  SelectTrigger,
  SelectValue,
  SelectContent,
  SelectItem,
} from "@/components/ui/select";
import Cookies from "js-cookie";
import useSWR from "swr";
import { Button } from "@/components/ui/button";
import { toast, ToastContainer } from "react-toastify";
import "react-toastify/dist/ReactToastify.css";
import { CgSpinner } from "react-icons/cg";
import { IoEyeOutline, IoEyeOffOutline } from "react-icons/io5";

// Skeleton Loader Component
const SkeletonLoader = ({ width = "100%", height = "40px" }) => (
  <div
    className="bg-gray-300 animate-pulse rounded"
    style={{ width, height }}
  ></div>
);

// Fetcher function for general API calls (unchanged)
const fetcher = async (url, token) => {
  if (!token) throw new Error("No token found");
  const res = await fetch(url, {
    headers: { Authorization: `Bearer ${token}` },
  });
  if (!res.ok) {
    const error = new Error("An error occurred while fetching the data.");
    error.status = res.status;
    throw error;
  }
  return res.json();
};

// OrderCard Component (made responsive)
const OrderCard = ({ order, onViewDetails }) => (
  <Card className="mb-4">
    <CardContent
      onClick={() => onViewDetails(order.order_id)}
      className="cursor-pointer p-4 bg-primary rounded-md border-none"
    >
      <div className="flex flex-col sm:flex-row justify-between items-start sm:items-center gap-2">
        <div>
          <p className="font-semibold text-white text-base sm:text-lg">
            #{order.tracking_id}
          </p>
          <p className="text-sm text-white">
            Date: <span className="font-semibold">{order.order_date}</span>
          </p>
        </div>
        <div>
          <p className="text-lg font-semibold text-white">
            ${parseFloat(order.grand_total).toFixed(2)}
          </p>
          <p className="text-lg font-semibold float-right mb-2">
            <Badge
              variant="outline"
              className={`text-white ${getStatusClass(order.order_status)}`}
            >
              {getStatusText(order.order_status)}
            </Badge>
          </p>
        </div>
      </div>
    </CardContent>
  </Card>
);

// OrderDetails Component (made responsive)
const OrderDetails = ({ order, onBack }) => (
  <Card className="border-none">
    <CardContent className="p-2 sm:p-4">
      <Button className="mb-4 w-full sm:w-auto" onClick={onBack}>
        Back to Orders
      </Button>
      <div className="space-y-4">
        {order.order_items.map((item) => (
          <div
            key={item.product_id}
            className="border border-primary rounded-lg p-3 sm:p-4 mb-4"
          >
            <div className="flex flex-col sm:flex-row justify-between items-start gap-3 sm:gap-4">
              <div className="flex gap-3 sm:gap-4 items-center w-full">
                <img
                  src={item.image}
                  alt={item.product_name}
                  className="w-16 h-16 sm:w-20 sm:h-20 object-cover rounded"
                />
                <div className="flex-1">
                  <p className="font-semibold text-base sm:text-lg">
                    {item.product_name}
                  </p>
                  <p className="text-xs sm:text-sm text-gray-600">
                    Store:{" "}
                    <span className="font-semibold">{item.store_name}</span>
                  </p>
                </div>
              </div>
              <div className="text-left sm:text-right w-full sm:w-auto">
                <p className="text-base sm:text-lg font-semibold">
                  Rs. {parseFloat(item.price).toFixed(2)}
                </p>
                <p className="text-xs sm:text-sm text-gray-600">
                  Qty: {item.quantity}
                </p>
              </div>
            </div>
          </div>
        ))}
      </div>
      <div className="grid md:grid-cols-2  gap-4 mt-4">
        <Card>
          <h4 className="text-sm sm:text-md font-semibold mb-2 rounded-t-md px-4 py-1 text-white bg-primary">
            Shipping Address
          </h4>
          <div className="p-2 sm:p-4">
            <p className="font-semibold text-sm sm:text-base">
              {order.customer_name}
            </p>
            <p className="text-xs sm:text-sm text-gray-600">{order.address}</p>
            <p className="text-xs sm:text-sm text-gray-600">{order.phone}</p>
            {order.second_phone && (
              <p className="text-xs sm:text-sm text-gray-600">
                {order.second_phone}
              </p>
            )}
          </div>
        </Card>
        <Card>
          <h4 className="text-sm sm:text-md font-semibold mb-2 rounded-t-md px-4 py-1 text-white bg-primary">
            Order Summary
          </h4>
          <div className="p-2 sm:p-4">
            <div className="flex justify-between text-xs sm:text-sm text-gray-600">
              <p>
                Items Total ({order.order_items?.length || 0} item
                {order.order_items?.length !== 1 ? "s" : ""})
              </p>
              <p>Rs. {parseFloat(order.total).toFixed(2)}</p>
            </div>
            <div className="flex justify-between text-xs sm:text-sm text-gray-600 mt-1">
              <p>Delivery Fee</p>
              <p>Rs. {parseFloat(order.delivery_fee).toFixed(2)}</p>
            </div>
            <div className="flex justify-between font-semibold mt-2 text-sm sm:text-base">
              <p>Total</p>
              <p>Rs. {parseFloat(order.grand_total).toFixed(2)}</p>
            </div>
          </div>
          <p className="text-xs sm:text-sm text-gray-600 mb-2 px-2">
            Pay by COD
          </p>
        </Card>
      </div>
    </CardContent>
  </Card>
);

// Main AccountSettings Component
export default function AccountSettings() {
  const token = Cookies.get("access_token");
  const baseUrl = process.env.NEXT_PUBLIC_BASE_URL;

  // Fetch user details and orders (unchanged)
  const { data: userData, error: userError } = useSWR(
    token ? `${baseUrl}userdetail` : null,
    (url) => fetcher(url, token)
  );
  const { data: ordersData, error: ordersError } = useSWR(
    token ? `${baseUrl}GetOrders` : null,
    (url) => fetcher(url, token)
  );

  const [formData, setFormData] = useState({
    userName: "",
    phoneNumber: "",
    dob: "",
    customer_gender: "",
    oldPassword: "",
    newPassword: "",
    confirmNewPassword: "",
  });

  const [passwordVisibility, setPasswordVisibility] = useState({
    oldPassword: false,
    newPassword: false,
    confirmNewPassword: false,
  });

  const [errors, setErrors] = useState({
    oldPassword: "",
    newPassword: "",
    confirmNewPassword: "",
  });

  const [isLoading, setIsLoading] = useState(false);
  const [selectedOrderId, setSelectedOrderId] = useState(null);
  const [orderDetails, setOrderDetails] = useState(null);

  // useEffect for user data and order details (unchanged)
  useEffect(() => {
    if (userData) {
      setFormData({
        userName: userData.user.user_name || "",
        phoneNumber: userData.user.customer_phone || "",
        dob: userData.user.customer_dob || "",
        customer_gender: userData.user.customer_gender || "",
        oldPassword: "",
        newPassword: "",
        confirmNewPassword: "",
      });
    }
  }, [userData]);

  useEffect(() => {
    if (selectedOrderId) {
      const fetchOrderDetails = async () => {
        try {
          const response = await fetch(
            `${baseUrl}GetOrderDetail?order_id=${selectedOrderId}`,
            {
              headers: { Authorization: `Bearer ${token}` },
            }
          );
          if (!response.ok) throw new Error("Failed to fetch order details");
          const data = await response.json();
          setOrderDetails(data.order);
        } catch (error) {
          console.error("Error fetching order details:", error);
          toast.error("Failed to load order details.");
          setSelectedOrderId(null);
        }
      };
      fetchOrderDetails();
    } else {
      setOrderDetails(null);
    }
  }, [selectedOrderId, token, baseUrl]);

  const handleChange = (e) => {
    const { name, value } = e.target;
    setFormData((prevState) => ({
      ...prevState,
      [name]: value,
    }));
    setErrors((prevErrors) => ({
      ...prevErrors,
      [name]: "",
    }));
  };

  const togglePasswordVisibility = (field) => {
    setPasswordVisibility((prev) => ({
      ...prev,
      [field]: !prev[field],
    }));
  };

  const validateForm = () => {
    let isValid = true;
    const newErrors = {};
    if (formData.newPassword !== formData.confirmNewPassword) {
      newErrors.confirmNewPassword = "Passwords do not match.";
      isValid = false;
    }
    if (formData.newPassword && formData.oldPassword === formData.newPassword) {
      newErrors.oldPassword =
        "New password cannot be the same as old password.";
      isValid = false;
    }
    setErrors(newErrors);
    return isValid;
  };

  const handleSave = async () => {
    if (!validateForm()) return;
    setIsLoading(true);
    try {
      const profileData = {
        user_name: formData.userName,
        customer_phone: formData.phoneNumber,
        customer_dob: formData.dob,
        customer_gender: formData.customer_gender,
      };
      if (formData.newPassword) {
        profileData.old_password = formData.oldPassword;
        profileData.new_password = formData.newPassword;
        profileData.confirm_password = formData.confirmNewPassword;
      }
      const profileResponse = await fetch(`${baseUrl}editProfile`, {
        method: "POST",
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
        },
        body: JSON.stringify(profileData),
      });
      if (!profileResponse.ok) throw new Error("Profile update failed.");
      toast.success("Changes saved successfully!");
    } catch (error) {
      console.error("Error saving data:", error);
      toast.error("An error occurred while saving the changes.");
    } finally {
      setIsLoading(false);
    }
  };

  if (userError)
    return <div className="p-4 text-center">Error loading user details</div>;

  return (
    <div className="max-w-7xl mx-auto p-4 sm:p-6">
      <ToastContainer />
      <Tabs
        defaultValue="profile"
        className="flex flex-col md:flex-row gap-4 sm:gap-6"
      >
        {/* Sidebar Tabs */}
        <div className="w-full md:w-1/4 bg-customOffWhite py-3 px-4 sm:px-5 border-2 rounded-md">
          <h2 className="text-base sm:text-lg font-semibold border-b pb-3 sm:pb-4">
            Account
          </h2>
          <TabsList className="flex flex-row md:flex-col gap-2 w-full overflow-x-auto md:overflow-visible">
            <TabsTrigger
              value="orders"
              className="font-normal text-sm sm:text-base text-left flex-1 md:flex-none whitespace-nowrap"
            >
              My Orders
            </TabsTrigger>
            <TabsTrigger
              value="profile"
              className="font-normal text-sm sm:text-base text-left flex-1 md:flex-none whitespace-nowrap"
            >
              Profile
            </TabsTrigger>
            <TabsTrigger
              value="password"
              className="font-normal text-sm sm:text-base text-left flex-1 md:flex-none whitespace-nowrap"
            >
              Change Password
            </TabsTrigger>
          </TabsList>
        </div>

        {/* Content Section */}
        <Card className="w-full md:w-3/4">
          <CardContent className="p-4 sm:p-6">
            <TabsContent value="profile">
              <h2 className="text-lg sm:text-xl font-semibold mb-4">Profile</h2>
              <div className="grid grid-cols-1 sm:grid-cols-2 gap-4">
                <div>
                  <Label className="text-sm sm:text-base">First Name</Label>
                  {userData ? (
                    <Input
                      name="userName"
                      value={formData.userName}
                      onChange={handleChange}
                      className="text-sm sm:text-base"
                    />
                  ) : (
                    <SkeletonLoader />
                  )}
                </div>
                <div>
                  <Label className="text-sm sm:text-base">Phone Number</Label>
                  {userData ? (
                    <Input
                      name="phoneNumber"
                      type="number"
                      value={formData.phoneNumber}
                      onChange={handleChange}
                      className="text-sm sm:text-base"
                    />
                  ) : (
                    <SkeletonLoader />
                  )}
                </div>
                <div>
                  <Label className="text-sm sm:text-base">Birthday</Label>
                  {userData ? (
                    <Input
                      name="dob"
                      type="date"
                      value={formData.dob}
                      onChange={handleChange}
                      className="text-sm sm:text-base"
                    />
                  ) : (
                    <SkeletonLoader />
                  )}
                </div>
                <div>
                  <Label className="text-sm sm:text-base">Gender</Label>
                  {userData ? (
                    <Select
                      name="customer_gender"
                      value={formData.customer_gender}
                      onValueChange={(value) =>
                        setFormData((prev) => ({
                          ...prev,
                          customer_gender: value,
                        }))
                      }
                    >
                      <SelectTrigger className="text-sm sm:text-base">
                        <SelectValue placeholder="Select Gender" />
                      </SelectTrigger>
                      <SelectContent>
                        <SelectItem value="Male">Male</SelectItem>
                        <SelectItem value="Female">Female</SelectItem>
                      </SelectContent>
                    </Select>
                  ) : (
                    <SkeletonLoader />
                  )}
                </div>
              </div>
              <Button
                className="mt-4 w-full sm:w-auto text-sm sm:text-base"
                onClick={handleSave}
              >
                {isLoading ? (
                  <CgSpinner
                    className="animate-spin text-lg sm:text-xl"
                    size="18"
                  />
                ) : (
                  "Save Changes"
                )}
              </Button>
            </TabsContent>

            <TabsContent value="password">
              <h2 className="text-lg sm:text-xl font-semibold mb-4">
                Change Password
              </h2>
              <div className="grid grid-cols-1 gap-4">
                <div>
                  <Label className="text-sm sm:text-base">Old Password</Label>
                  <div className="relative">
                    <Input
                      type={
                        passwordVisibility.oldPassword ? "text" : "password"
                      }
                      name="oldPassword"
                      value={formData.oldPassword}
                      onChange={handleChange}
                      className="text-sm sm:text-base"
                    />
                    <button
                      type="button"
                      className="absolute right-3 top-1/2 transform -translate-y-1/2"
                      onClick={() => togglePasswordVisibility("oldPassword")}
                    >
                      {passwordVisibility.oldPassword ? (
                        <IoEyeOffOutline className="text-lg sm:text-xl" />
                      ) : (
                        <IoEyeOutline className="text-lg sm:text-xl" />
                      )}
                    </button>
                  </div>
                  {errors.oldPassword && (
                    <p className="text-red-500 text-xs sm:text-sm">
                      {errors.oldPassword}
                    </p>
                  )}
                </div>
                <div>
                  <Label className="text-sm sm:text-base">New Password</Label>
                  <div className="relative">
                    <Input
                      type={
                        passwordVisibility.newPassword ? "text" : "password"
                      }
                      name="newPassword"
                      value={formData.newPassword}
                      onChange={handleChange}
                      className="text-sm sm:text-base"
                    />
                    <button
                      type="button"
                      className="absolute right-3 top-1/2 transform -translate-y-1/2"
                      onClick={() => togglePasswordVisibility("newPassword")}
                    >
                      {passwordVisibility.newPassword ? (
                        <IoEyeOffOutline className="text-lg sm:text-xl" />
                      ) : (
                        <IoEyeOutline className="text-lg sm:text-xl" />
                      )}
                    </button>
                  </div>
                  {errors.newPassword && (
                    <p className="text-red-500 text-xs sm:text-sm">
                      {errors.newPassword}
                    </p>
                  )}
                </div>
                <div>
                  <Label className="text-sm sm:text-base">
                    Confirm New Password
                  </Label>
                  <div className="relative">
                    <Input
                      type={
                        passwordVisibility.confirmNewPassword
                          ? "text"
                          : "password"
                      }
                      name="confirmNewPassword"
                      value={formData.confirmNewPassword}
                      onChange={handleChange}
                      className="text-sm sm:text-base"
                    />
                    <button
                      type="button"
                      className="absolute right-3 top-1/2 transform -translate-y-1/2"
                      onClick={() =>
                        togglePasswordVisibility("confirmNewPassword")
                      }
                    >
                      {passwordVisibility.confirmNewPassword ? (
                        <IoEyeOffOutline className="text-lg sm:text-xl" />
                      ) : (
                        <IoEyeOutline className="text-lg sm:text-xl" />
                      )}
                    </button>
                  </div>
                  {errors.confirmNewPassword && (
                    <p className="text-red-500 text-xs sm:text-sm">
                      {errors.confirmNewPassword}
                    </p>
                  )}
                </div>
              </div>
              <Button
                className="mt-4 w-full sm:w-auto text-sm sm:text-base"
                onClick={handleSave}
              >
                {isLoading ? (
                  <CgSpinner
                    className="animate-spin text-lg sm:text-xl"
                    size="18"
                  />
                ) : (
                  "Save Changes"
                )}
              </Button>
            </TabsContent>

            <TabsContent value="orders">
              <h2 className="text-lg sm:text-xl font-semibold mb-4">
                My Orders
              </h2>
              {ordersError && (
                <div className="text-center">Error loading orders</div>
              )}
              {!ordersData && !ordersError && (
                <div className="space-y-4">
                  <SkeletonLoader height="100px" />
                  <SkeletonLoader height="100px" />
                </div>
              )}
              {ordersData && ordersData.orders.length === 0 && (
                <p className="text-center">No orders found.</p>
              )}
              {ordersData &&
                ordersData.orders.length > 0 &&
                !selectedOrderId && (
                  <div className="space-y-4">
                    {ordersData.orders.map((order) => (
                      <OrderCard
                        key={order.order_id}
                        order={order}
                        onViewDetails={setSelectedOrderId}
                      />
                    ))}
                  </div>
                )}
              {selectedOrderId &&
                (orderDetails ? (
                  <OrderDetails
                    order={orderDetails}
                    onBack={() => setSelectedOrderId(null)}
                  />
                ) : (
                  <div className="space-y-4">
                    <SkeletonLoader height="100px" />
                    <SkeletonLoader height="100px" />
                    <div className="grid md:grid-cols-2 gap-4 sm:gap-6 mt-4">
                      <SkeletonLoader height="150px" />
                      <SkeletonLoader height="150px" />
                    </div>
                  </div>
                ))}
            </TabsContent>
          </CardContent>
        </Card>
      </Tabs>
    </div>
  );
}
